aboutsummaryrefslogtreecommitdiff
path: root/gcc/testsuite/gcc.c-torture/execute/20101011-1.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/testsuite/gcc.c-torture/execute/20101011-1.c')
-rw-r--r--gcc/testsuite/gcc.c-torture/execute/20101011-1.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gcc/testsuite/gcc.c-torture/execute/20101011-1.c b/gcc/testsuite/gcc.c-torture/execute/20101011-1.c
index 639d12d..e7157c5 100644
--- a/gcc/testsuite/gcc.c-torture/execute/20101011-1.c
+++ b/gcc/testsuite/gcc.c-torture/execute/20101011-1.c
@@ -45,7 +45,7 @@
# define DO_TEST 0
#elif defined (__epiphany__)
/* Epiphany does not have hardware division, and the software implementation
- has truly undefined behaviour for division by 0. */
+ has truly undefined behavior for division by 0. */
# define DO_TEST 0
#elif defined (__m68k__) && !defined(__linux__)
/* Attempting to trap division-by-zero in this way isn't likely to work on
@@ -68,9 +68,9 @@
# define DO_TEST 0
# else
# include <signal.h>
/* ARM division-by-zero behaviour is to call a helper function, which
can do several different things, depending on requirements. Emulate
- the behaviour of other targets here by raising SIGFPE. */
+ the behavior of other targets here by raising SIGFPE. */
int __attribute__((used))
__aeabi_idiv0 (int return_value)
{
@@ -68,9 +68,9 @@
# else
# include <signal.h>
- /* ARM division-by-zero behaviour is to call a helper function, which
+ /* ARM division-by-zero behavior is to call a helper function, which
can do several different things, depending on requirements. Emulate